@@ -13,7 +13,7 @@ use Digest::MD5 qw(md5_hex);
 use Errno;
 use Data::Dumper;
 our $AUTOLOAD;
-*VERSION = \'2.0.10';
+*VERSION = \'2.0.18';
 
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
@@ -372,9 +372,9 @@ sub validate_args {
 }
 
 sub set_timeout_alarm {
-  my ($self, $timeout) = @_;
-  my $timeout = defined $timeout ? int($timeout) : $self->opts->timeout;
-  my $handler = sub {
+  my ($self, $timeout, $handler) = @_;
+  $timeout ||= $self->opts->timeout;
+  $handler ||= sub {
     printf "UNKNOWN - %s timed out after %d seconds\n",
         $Monitoring::GLPlugin::plugin->{name}, $self->opts->timeout;
     exit 3;
@@ -390,7 +390,7 @@ sub set_timeout_alarm {
     my $oldaction = POSIX::SigAction->new();
     sigaction(SIGALRM ,$action ,$oldaction );
   }    
-  alarm($timeout); # 1 second before the global unknown timeout
+  alarm(int($timeout)); # 1 second before the global unknown timeout
 }
 
 #########################################################
@@ -796,6 +796,42 @@ sub add_unknown {
   $self->add_message(UNKNOWN, $message);
 }
 
+sub add_ok_mitigation {
+  my ($self, $message) = @_;
+  if (defined $self->opts->mitigation()) {
+    $self->add_message($self->opts->mitigation(), $message);
+  } else {
+    $self->add_ok($message);
+  }
+}
+
+sub add_warning_mitigation {
+  my ($self, $message) = @_;
+  if (defined $self->opts->mitigation()) {
+    $self->add_message($self->opts->mitigation(), $message);
+  } else {
+    $self->add_warning($message);
+  }
+}
+
+sub add_critical_mitigation {
+  my ($self, $message) = @_;
+  if (defined $self->opts->mitigation()) {
+    $self->add_message($self->opts->mitigation(), $message);
+  } else {
+    $self->add_critical($message);
+  }
+}
+
+sub add_unknown_mitigation {
+  my ($self, $message) = @_;
+  if (defined $self->opts->mitigation()) {
+    $self->add_message($self->opts->mitigation(), $message);
+  } else {
+    $self->add_unknown($message);
+  }
+}
+
 sub add_message {
   my ($self, $level, $message) = @_;
   $message ||= $self->{info};
@@ -1205,7 +1241,15 @@ sub create_statefile {
   $extension =~ s/\*/_/g;
   $extension =~ s/\s/_/g;
   return sprintf "%s/%s%s", $self->statefilesdir(),
-      $self->mode, lc $extension;
+      $self->clean_path($self->mode), $self->clean_path(lc $extension);
+}
+
+sub clean_path {
+  my ($self, $path) = @_;
+  if ($^O =~ /MSWin/) {
+    $path =~ s/:/_/g;
+  }
+  return $path;
 }
 
 sub schimpf {
