@@ -1,5 +1,6 @@
 package Monitoring::GLPlugin::Commandline;
 use strict;
+use IO::File;
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3, DEPENDENT => 4 };
 our %ERRORS = (
     'OK'        => OK,
@@ -14,8 +15,7 @@ our $AUTOLOAD;
 
 
 sub new {
-  my $class = shift;
-  my %params = @_;
+  my ($class, %params) = @_;
   require Monitoring::GLPlugin::Commandline::Getopt
       if ! grep /BEGIN/, keys %Monitoring::GLPlugin::Commandline::Getopt::;
   my $self = {
@@ -42,38 +42,37 @@ sub new {
 }
 
 sub AUTOLOAD {
-  my $self = shift;
+  my ($self, @params) = @_;
   return if ($AUTOLOAD =~ /DESTROY/);
   $self->debug("AUTOLOAD %s\n", $AUTOLOAD)
         if $self->{opts}->verbose >= 2;
   if ($AUTOLOAD =~ /^.*::(add_arg|override_opt|create_opt)$/) {
-    $self->{opts}->$1(@_);
+    $self->{opts}->$1(@params);
   }
 }
 
 sub DESTROY {
-  my $self = shift;
+  my ($self) = @_;
   # ohne dieses DESTROY rennt nagios_exit in obiges AUTOLOAD rein
   # und fliegt aufs Maul, weil {opts} bereits nicht mehr existiert.
   # Unerklaerliches Verhalten.
 }
 
 sub debug {
-  my $self = shift;
-  my $format = shift;
+  my ($self, $format, @message) = @_;
   my $tracefile = "/tmp/".$Monitoring::GLPlugin::pluginname.".trace";
   $self->{trace} = -f $tracefile ? 1 : 0;
   if ($self->opts->verbose && $self->opts->verbose > 10) {
     printf("%s: ", scalar localtime);
-    printf($format, @_);
+    printf($format, @message);
     printf "\n";
   }
   if ($self->{trace}) {
-    my $logfh = new IO::File;
+    my $logfh = IO::File->new();
     $logfh->autoflush(1);
     if ($logfh->open($tracefile, "a")) {
       $logfh->printf("%s: ", scalar localtime);
-      $logfh->printf($format, @_);
+      $logfh->printf($format, @message);
       $logfh->printf("\n");
       $logfh->close();
     }
@@ -81,26 +80,24 @@ sub debug {
 }
 
 sub opts {
-  my $self = shift;
+  my ($self) = @_;
   return $self->{opts};
 }
 
 sub getopts {
-  my $self = shift;
+  my ($self) = @_;
   $self->opts->getopts();
 }
 
 sub add_message {
-  my $self = shift;
-  my ($code, @messages) = @_;
+  my ($self, $code, @messages) = @_;
   $code = (qw(ok warning critical unknown))[$code] if $code =~ /^\d+$/;
   $code = lc $code;
   push @{$self->{messages}->{$code}}, @messages;
 }
 
 sub selected_perfdata {
-  my $self = shift;
-  my $label = shift;
+  my ($self, $label) = @_;
   if ($self->opts->can("selectedperfdata") && $self->opts->selectedperfdata) {
     my $pattern = $self->opts->selectedperfdata;
     return ($label =~ /$pattern/i) ? 1 : 0;
@@ -222,27 +219,25 @@ sub add_perfdata {
 }
 
 sub add_html {
-  my $self = shift;
-  my $line = shift;
+  my ($self, $line) = @_;
   push @{$self->{html}}, $line;
 }
 
 sub suppress_messages {
-  my $self = shift;
+  my ($self) = @_;
   $self->{suppress_messages} = 1;
 }
 
 sub clear_messages {
-  my $self = shift;
-  my $code = shift;
+  my ($self, $code) = @_;
   $code = (qw(ok warning critical unknown))[$code] if $code =~ /^\d+$/;
   $code = lc $code;
   $self->{messages}->{$code} = [];
 }
 
 sub reduce_messages_short {
-  my $self = shift;
-  my $message = shift || "no problems";
+  my ($self, $message) = @_;
+  $message ||= "no problems";
   if ($self->opts->report && $self->opts->report eq "short") {
     $self->clear_messages(OK);
     $self->add_message(OK, $message) if ! $self->check_messages();
@@ -250,15 +245,14 @@ sub reduce_messages_short {
 }
 
 sub reduce_messages {
-  my $self = shift;
-  my $message = shift || "no problems";
+  my ($self, $message) = @_;
+  $message ||= "no problems";
   $self->clear_messages(OK);
   $self->add_message(OK, $message) if ! $self->check_messages();
 }
 
 sub check_messages {
-  my $self = shift;
-  my %args = @_;
+  my ($self, %args) = @_;
 
   # Add object messages to any passed in as args
   for my $code (qw(critical warning unknown ok)) {
@@ -311,8 +305,7 @@ sub check_messages {
 }
 
 sub status_code {
-  my $self = shift;
-  my $code = shift;
+  my ($self, $code) = @_;
   $code = (qw(ok warning critical unknown))[$code] if $code =~ /^\d+$/;
   $code = uc $code;
   $code = $ERRORS{$code} if defined $code && exists $ERRORS{$code};
@@ -321,7 +314,7 @@ sub status_code {
 }
 
 sub perfdata_string {
-  my $self = shift;
+  my ($self) = @_;
   if (scalar (@{$self->{perfdata}})) {
     return join(" ", @{$self->{perfdata}});
   } else {
@@ -330,7 +323,7 @@ sub perfdata_string {
 }
 
 sub html_string {
-  my $self = shift;
+  my ($self) = @_;
   if (scalar (@{$self->{html}})) {
     return join(" ", @{$self->{html}});
   } else {
@@ -339,8 +332,7 @@ sub html_string {
 }
 
 sub nagios_exit {
-  my $self = shift;
-  my ($code, $message, $arg) = @_;
+  my ($self, $code, $message, $arg) = @_;
   $code = $ERRORS{$code} if defined $code && exists $ERRORS{$code};
   $code = UNKNOWN unless defined $code && exists $STATUS_TEXT{$code};
   $message = '' unless defined $message;
@@ -372,6 +364,7 @@ sub nagios_exit {
       }
     }
   }
+  $output =~ s/\|/!/g if $output;
   if (scalar (@{$self->{perfdata}})) {
     $output .= " | ".$self->perfdata_string();
   }
@@ -388,8 +381,7 @@ sub nagios_exit {
 }
 
 sub set_thresholds {
-  my $self = shift;
-  my %params = @_;
+  my ($self, %params) = @_;
   if (exists $params{metric}) {
     my $metric = $params{metric};
     # erst die hartcodierten defaultschwellwerte
@@ -424,8 +416,7 @@ sub set_thresholds {
 }
 
 sub force_thresholds {
-  my $self = shift;
-  my %params = @_;
+  my ($self, %params) = @_;
   if (exists $params{metric}) {
     my $metric = $params{metric};
     $self->{thresholds}->{$metric}->{warning} = $params{warning} || 0;
@@ -437,8 +428,7 @@ sub force_thresholds {
 }
 
 sub get_thresholds {
-  my $self = shift;
-  my @params = @_;
+  my ($self, @params) = @_;
   if (scalar(@params) > 1) {
     my %params = @params;
     my $metric = $params{metric};
@@ -451,8 +441,7 @@ sub get_thresholds {
 }
 
 sub check_thresholds {
-  my $self = shift;
-  my @params = @_;
+  my ($self, @params) = @_;
   my $level = $ERRORS{OK};
   my $warningrange;
   my $criticalrange;
